__version__ = '2.2.0'


from .attrs2 import Attr, Attrs, BoundAttr, NotSet, Required, container

__all__ = [
    'Attr',
    'Attrs',
    'BoundAttr',
    'NotSet',
    'Required',
    'container',
]
